stacd.design <-
function(x,z){

	### check valid input

	if(!is.numeric(x) || !is.numeric(z)){
		stop("Input data must be numeric")
	}
	if(length(x)!=length(z)){
		stop("Data for SNPs x and z must be of the same dimension")
	}
	if(any(is.na(match(x,c(0,1,2,NA))))){
		stop("Invalid valus in x. All values must be 0,1,2, or NA.")
	}
	if(any(is.na(match(z,c(0,1,2,NA))))){
		stop("Invalid valus in z. All values must be 0,1,2, or NA.")
	}

	### build design matrix	
	design <- data.frame(
		as.numeric(x),				# alpha_1
		as.numeric(x==2),			# alpha_2
		as.numeric(z),				# beta_1
		as.numeric(z==2),			# beta_2
		as.numeric((x*z)>0),		# gamma_ab
		as.numeric((x==2)*(z>0)),	# gamma^*_aab
		as.numeric((x>0)*(z==2)),	# gamma^*_abb
		as.numeric((x==2)*(z==2))	# gamma^*_aabb
	)
	colnames(design) <- c("alpha_1","alpha_2",
		"beta_1","beta_2","gamma_ab","gamma^*_aab",
		"gamma^*_abb","gamma^*_aabb")

	return(design)
}

